@@ -21,20 +21,14 @@ import shutil
 import pathlib
 import glob
 import re
-#from ml_track_tool.flask_app import create_application
-
-
-# In[2]:
-
 
 pd.set_option('colheader_justify', 'center')
 
 
-# In[3]:
-
 
 def create_application(path):
     app=Flask(__name__)
+    path=path.replace("\\","/")
     current_path=pathlib.Path(__file__).parent.resolve()
     my_loader = jinja2.ChoiceLoader([
         app.jinja_loader,
@@ -54,7 +48,7 @@ def create_application(path):
         
         else:
             folders=os.listdir(path)
-            print(folders)
+
             return render_template("experiment_page.html",folders=folders)
         
     @app.route('/home2/<experiment>',methods=["POST","GET"])
@@ -63,9 +57,7 @@ def create_application(path):
         
             notes=request.form['text']
             text_file = open(f"{path}/team_notes/notes.txt", "w")
-            #write string to file
             text_file.write(notes)
-            #close file
             text_file.close()
             download_path=f"{Path.home()}/Downloads/*.csv".replace("\\","/")
             latest_file=get_latest_file(download_path)
@@ -86,7 +78,7 @@ def create_application(path):
                 table_path="none"
             
             memory_path=f"{path+'/'+exp_folder}/memory_info/memory_metrics.json"
-            history_path=f"{path+'/'+exp_folder}/performance/history.json"
+            history_path=f"{path+'/'+exp_folder}/performance/performance.json"
             prediction_path=f"{path+'/'+exp_folder}/prediction/prediction.json"
 
             memory_file_path_exists=False
